aboutsummaryrefslogtreecommitdiffstats
path: root/src/0x.ts
diff options
context:
space:
mode:
authorLeonid Logvinov <logvinov.leon@gmail.com>2017-08-22 17:28:26 +0800
committerLeonid Logvinov <logvinov.leon@gmail.com>2017-08-22 19:28:05 +0800
commitb2b5abadb22420650334041f9560e3ac4e5b7e41 (patch)
treeaddd32fe30c217f07b4251828c224df265a10d5e /src/0x.ts
parent0bc9083bff341cc7841fb1ccd84fa50e6749151d (diff)
downloaddexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar.gz
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar.bz2
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar.lz
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar.xz
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.tar.zst
dexon-sol-tools-b2b5abadb22420650334041f9560e3ac4e5b7e41.zip
Rename internally Proxy to TokenTransferProxy
Diffstat (limited to 'src/0x.ts')
-rw-r--r--src/0x.ts10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/0x.ts b/src/0x.ts
index b581d242d..e7c10fb73 100644
--- a/src/0x.ts
+++ b/src/0x.ts
@@ -15,7 +15,7 @@ import {TokenRegistryWrapper} from './contract_wrappers/token_registry_wrapper';
import {EtherTokenWrapper} from './contract_wrappers/ether_token_wrapper';
import {ecSignatureSchema} from './schemas/ec_signature_schema';
import {TokenWrapper} from './contract_wrappers/token_wrapper';
-import {ProxyWrapper} from './contract_wrappers/proxy_wrapper';
+import {TokenTransferProxyWrapper} from './contract_wrappers/token_transfer_proxy_wrapper';
import {ECSignature, ZeroExError, Order, SignedOrder, Web3Provider} from './types';
import {orderHashSchema} from './schemas/order_hash_schema';
import {orderSchema} from './schemas/order_schemas';
@@ -55,10 +55,10 @@ export class ZeroEx {
*/
public etherToken: EtherTokenWrapper;
/**
* An instance of the ProxyWrapper class containing methods for interacting with the
* proxy smart contract.
*/
- public proxy: ProxyWrapper;
+ public proxy: TokenTransferProxyWrapper;
private _web3Wrapper: Web3Wrapper;
/**
* Verifies that the elliptic curve signature `signature` was generated
@@ -167,7 +167,7 @@ export class ZeroEx {
constructor(provider: Web3Provider) {
this._web3Wrapper = new Web3Wrapper(provider);
this.token = new TokenWrapper(this._web3Wrapper);
- this.proxy = new ProxyWrapper(this._web3Wrapper);
+ this.proxy = new TokenTransferProxyWrapper(this._web3Wrapper);
this.exchange = new ExchangeWrapper(this._web3Wrapper, this.token);
this.tokenRegistry = new TokenRegistryWrapper(this._web3Wrapper);
this.etherToken = new EtherTokenWrapper(this._web3Wrapper, this.token);
@@ -55,10 +55,10 @@ export class ZeroEx {
public etherToken: EtherTokenWrapper;
/**
- * An instance of the ProxyWrapper class containing methods for interacting with the
- * proxy smart contract.
+ * An instance of the TokenTransferProxyWrapper class containing methods for interacting with the
+ * tokenTransferProxy smart contract.
*/